/*
 *   This file is part of the MLV Library.
 *
 *   Copyright (C) 2010 Adrien Boussicault, Marc Zipstein
 *
 *
 *    This Library is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This Library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this Library.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "MLV_animation.h"
#include "MLV_path.h"

#include "warning_error.h"

#include "memory_management.h"

#include "MLV_xml.h"

#include <glib.h>


////////////////////////////////////////////////
//    Animation structures
///////////////////////////////////////////////

typedef struct {
 	MLV_Image** images; // Layer of images
 	MLV_Sound** sounds; // Layer of images
	unsigned int delay;
} Animation_frame;

struct _MLV_Animation_sequence {
	unsigned int max_frames;
	unsigned int nb_frames;
	unsigned int nb_layers;
	unsigned int nb_channels;
	Animation_frame * frames;
};

struct _MLV_Animation {
	int* state_sound;
	int sounds_are_being_played;
	float* volume;
	const MLV_Animation_sequence * animation_sequence;
	enum { STOP, PLAY, PLAY_REVERT } status;
	unsigned int current_frame;
	unsigned int counter;
};


////////////////////////////////////////////////
//    Animation data
///////////////////////////////////////////////

MLV_Animation_sequence* MLV_create_animation_sequence(
	unsigned int max_frames, unsigned int nb_layers, unsigned int nb_channels
){
	MLV_Animation_sequence* result = MLV_MALLOC( 1, MLV_Animation_sequence );
	result->nb_frames = 0;
	result->max_frames = max_frames;
	result->nb_layers = nb_layers;
	result->nb_channels = nb_channels;
	result->frames = MLV_MALLOC( max_frames, Animation_frame );
	int i,j;
	for( i=0; i<max_frames; i++ ){
		if( nb_layers>0 ){
			result->frames[i].images = MLV_MALLOC( nb_layers, MLV_Image* );
			for( j=0; j<nb_layers; j++ ){
				result->frames[i].images[j] = NULL;
			}
		}else{
			result->frames[i].images = NULL;
		}
		if( nb_channels>0 ){
			result->frames[i].sounds = MLV_MALLOC( nb_channels, MLV_Sound* );
			for( j=0; j<nb_channels; j++ ){
				result->frames[i].sounds[j] = NULL;
			}
		}else{
			result->frames[i].sounds = NULL;
		}
	}
	return result;
}

void MLV_free_animation_sequence( MLV_Animation_sequence* animation_sequence ){
	int i;
	for( i=0; i<animation_sequence->nb_frames; i++ ){
		MLV_FREE( animation_sequence->frames[i].images, MLV_Image* );
		MLV_FREE( animation_sequence->frames[i].sounds, MLV_Image* );
	}
	MLV_FREE( animation_sequence->frames, Animation_frame );
	MLV_FREE( animation_sequence, MLV_Animation_sequence );
}

void user_is_modifying_animation(
	MLV_Animation_sequence* animation_sequence, unsigned int position
){
	if( position < animation_sequence->max_frames ){
		if( position >= animation_sequence->nb_frames ){
			animation_sequence->nb_frames = position+1;
		}
	}else{
		char* text;
		int error = asprintf(
			&text,
			"Tou can-t add or modify an image at the position %d, you have created an animation with only %d images.", 
			position, animation_sequence->max_frames 
		);
		if( error==-1){
			ERROR_FULL("Allocation memoy problem.");
		}
		ERROR( text );
		MLV_FREE(text, char);
	}
}

void MLV_change_frame_in_animation_sequence(
	MLV_Image** array_of_images, MLV_Sound** array_of_sounds, unsigned int delay,
	MLV_Animation_sequence* animation_sequence, unsigned int position
){
	user_is_modifying_animation( animation_sequence, position );
	if( array_of_images ){
		int layer;
		for( layer=0; layer<animation_sequence->nb_layers; layer ++){
			animation_sequence->frames[
				position
			].images[layer] = array_of_images[layer];
		}
	}
	if( array_of_sounds ){
		int channel;
		for( channel=0; channel<animation_sequence->nb_channels; channel++ ){
			animation_sequence->frames[
				position
			].sounds[channel] = array_of_sounds[channel];
		}
	}
	animation_sequence->frames[position].delay = delay;
}

void MLV_add_frame_in_animation_sequence(
	MLV_Image** array_of_images, MLV_Sound** array_of_sounds, unsigned int delay,
	MLV_Animation_sequence* animation_sequence
){
	MLV_change_frame_in_animation_sequence(
		array_of_images, array_of_sounds, delay, animation_sequence, 
		animation_sequence->nb_frames
	);
}

void MLV_change_frame_image_in_animation_sequence(
	MLV_Image* image, MLV_Animation_sequence* animation_sequence,
	unsigned int position, unsigned int layer
){
	user_is_modifying_animation( animation_sequence, position );
	animation_sequence->frames[position].images[layer] = image;
}

void MLV_change_frame_sound_in_animation_sequence(
	MLV_Sound* sound, MLV_Animation_sequence* animation_sequence,
	unsigned int position, unsigned int channel
){
	user_is_modifying_animation( animation_sequence, position );
	animation_sequence->frames[position].sounds[channel] = sound;
}

void MLV_change_frame_delay_in_animation_sequence(
	unsigned int delay, MLV_Animation_sequence* animation_sequence,
	unsigned int position
){
	user_is_modifying_animation( animation_sequence, position );
	animation_sequence->frames[position].delay = delay;
}

void MLV_get_frame_from_animation_sequence(
	MLV_Animation_sequence* animation_sequence, unsigned int position, unsigned int layer, 
	MLV_Image** image, unsigned int* delay
){
	TODO
}

int MLV_get_frame_delay_from_animation_sequence(
	MLV_Animation_sequence* animation_sequence, unsigned int position
){
	return animation_sequence->frames[position].delay;
}

MLV_Image* MLV_get_frame_image_from_animation_sequence(
	MLV_Animation_sequence* animation_sequence, unsigned int position,
	unsigned int layer
){
	return animation_sequence->frames[position].images[layer];
}


////////////////////////////////////////////////
//    Animation engine
///////////////////////////////////////////////

MLV_Animation* MLV_create_animation(
	MLV_Animation_sequence* animation_sequence
){
	int nb_channels = animation_sequence->nb_channels;
	MLV_Animation* result = MLV_MALLOC( 1, MLV_Animation );
	if( nb_channels>0 ){
		result->volume = MLV_MALLOC( nb_channels, float );
		result->sounds_are_being_played = 0;
		result->state_sound = MLV_MALLOC( nb_channels, int );
		int channel;
		for( channel=0; channel<nb_channels; channel++ ){
			result->volume[channel]=0;
			result->state_sound[channel] = 0;
		}
	}else{
		result->volume = NULL;
		result->state_sound = NULL;
	}
	result->animation_sequence = animation_sequence;
	MLV_rewind_animation( result );
	return result;
}
void MLV_free_animation( MLV_Animation* animation ){
	MLV_FREE( animation->volume, float );
	MLV_FREE( animation->state_sound, int );
	MLV_FREE( animation, MLV_Animation );
}

void MLV_play_animation( MLV_Animation* animation ){
	animation->status = PLAY;
}
void MLV_play_revert_animation( MLV_Animation* animation ){
	animation->status = PLAY_REVERT;
}
void MLV_stop_animation( MLV_Animation* animation ){
	animation->status = STOP;
}
void MLV_rewind_animation( MLV_Animation* animation ){
	animation->current_frame = 0;
	animation->counter = 0;
	MLV_stop_animation( animation );
}
void MLV_next_frame( MLV_Animation* animation ){
	/* Retour à la frame 0 si nous sommes à la dernière */
	if( 
		++animation->current_frame == 
			animation->animation_sequence->nb_frames
	){
		animation->current_frame = 0;
	}
   animation->counter = 0;
}
void MLV_previous_frame(
	MLV_Animation* animation
){
	/* Retour à la frame 0 si nous sommes à la dernière */
	if ( --animation->current_frame == -1 ){
		animation->current_frame = 
			animation->animation_sequence->nb_frames-1;
	}
   animation->counter = 0;
}

void MLV_update_animation( MLV_Animation* animation ){
	int channel;
	const Animation_frame * frame;

	if( animation->status == STOP ) return;

	frame = &animation->animation_sequence->frames[
		animation->current_frame
	];

	// On lance les différents effets sonnores associe a l'animation
	if( ! animation->sounds_are_being_played ){
		for(
			channel = 0; channel < animation->animation_sequence->nb_channels;
			channel++
		){
			MLV_Sound* sound = frame->sounds[channel];
			if( animation->state_sound[channel] && sound ){
				MLV_play_sound( sound, animation->volume[channel] );
			}
		}
		animation->sounds_are_being_played = 1;
	}

	if (frame->delay == 0) return;

	// Passage à la frame suivante
	if( ++animation->counter == frame->delay ){
		switch( animation->status ){
			case PLAY:
					MLV_next_frame(animation);
				break;
			case PLAY_REVERT:
					MLV_previous_frame(animation);
				break;
			default:
				return;
		}
		animation->sounds_are_being_played = 0;
	}
}


void MLV_change_sound_volume_on_animation(
	MLV_Animation* animation, unsigned int channel, float volume
){
	animation->volume[channel]=volume;
}

void MLV_turn_on_sound_on_animation(
	MLV_Animation* animation, unsigned int channel
){
	animation->state_sound[channel]=1;
}

void MLV_turn_off_sound_on_animation(
	MLV_Animation* animation, unsigned int channel
){
	animation->state_sound[channel]=0;
}


////////////////////////////////////////////////
//    Drawing animation
///////////////////////////////////////////////

void MLV_draw_animation(
	MLV_Animation* animation, unsigned int layer,
	int x, int y
){
	MLV_draw_image( 
		animation->animation_sequence->frames[
			animation->current_frame
		].images[layer],
		x,y
	);
}

void MLV_draw_animation_on_image(
	MLV_Animation* animation, unsigned int layer,
	MLV_Image* image,
	int x, int y
){
	MLV_draw_image_on_image( 
		animation->animation_sequence->frames[
			animation->current_frame
		].images[layer],
		image,
		x,y
	);
}

void MLV_draw_partial_animation_on_image(
	MLV_Animation* animation, unsigned int layer,
	int source_x, int source_y, int source_width, int source_height,
	MLV_Image* image,
	int x, int y
){
	MLV_draw_partial_image_on_image(
		animation->animation_sequence->frames[
			animation->current_frame
		].images[layer],
		source_x, source_y, source_width, source_height,
		image,
		x, y
	);
}

void MLV_draw_partial_animation(
	MLV_Animation* animation, unsigned int layer,
	int source_x, int source_y, int source_width, int source_height,
	MLV_Image* image,
	int x, int y
){
	MLV_draw_partial_image(
		animation->animation_sequence->frames[
			animation->current_frame
		].images[layer],
		source_x, source_y, source_width, source_height,
		x, y
	);
}


////////////////////////////////////////////////
//    Loading animation_sequences from files
//    stored in animation books.
///////////////////////////////////////////////

typedef struct _Animation_book_sound {
	char* name;
	MLV_Sound** channels;
} Animation_book_sound;

typedef struct _Animation_book_page {
	int width;
	int height;
	int columns;
	MLV_Image** layers;
} Animation_book_page;

struct _MLV_Animation_book {
	char* xml_file;

	int nb_channels;
	GData* channel_name_to_id;
	char** channel_names;

	int nb_layers;
	GData* layer_name_to_id;
	char** layer_names;

	int nb_pages;
	GData* page_name_to_id;
	char** page_names;
	Animation_book_page* pages;

	int nb_sounds;
	GData* sound_name_to_id;
	char** sound_names;
	Animation_book_sound* sounds;

	int nb_animation_sequences;
	GData* animation_name_to_id;
	char** animation_names;
	MLV_Animation_sequence** animation_sequences;

};

int MLV_get_number_of_animation_sequences(
	MLV_Animation_book* animation_book
){
	return animation_book->nb_animation_sequences;
}

void GDestroyNotify_int( gpointer data ){
	int* ptr = (int*) data;
	MLV_FREE( ptr, int);
}

void insret_data_in_map( GData** map, char* name, int identifiant ){
	int* id = MLV_MALLOC( 1, int );
	*id = identifiant;
	g_datalist_set_data_full( map, name, id, &GDestroyNotify_int );
}

MLV_Animation_book* MLV_load_animation_book(
	const char* xml_file,
	const char* image_directory,
	const char* sound_directory
){
	int i;
	MLV_Animation_book* result;

	char* dirname = MLV_get_directory_name( xml_file );

	MLV_Xml* xml = MLV_load_xml( xml_file );

	if( !xml ) return NULL;

	result = MLV_MALLOC( 1, MLV_Animation_book );

	result->nb_animation_sequences = MLV_get_number_of_objects_from_xml(
		xml, "/animation_book/animation"
	);
	result->animation_sequences = MLV_MALLOC(
		result->nb_animation_sequences, MLV_Animation_sequence*
	);
	result->animation_names = MLV_MALLOC(
		result->nb_animation_sequences, char*
	);
	g_datalist_init( &(result->animation_name_to_id) );
	for( i=0; i<result->nb_animation_sequences; i++ ){
		result->animation_names[i] = MLV_get_string_value_from_xml(
			xml, 0, "/animation_book/animation[%d]/name", i+1
		);
		insret_data_in_map(
			&(result->animation_name_to_id), result->animation_names[i], i
		);
	}

	result->nb_layers = MLV_get_number_of_objects_from_xml(
		xml, "/animation_book/layers/layer"
	);
	result->layer_names = MLV_MALLOC(
		result->nb_layers, char*
	);
	g_datalist_init( &(result->layer_name_to_id) );
	for( i=0; i<result->nb_layers; i++ ){
		result->layer_names[i] = MLV_get_string_value_from_xml(
			xml, 0, "/animation_book/layers/layer[%d]", i+1
		);
		insret_data_in_map(
			&(result->layer_name_to_id), result->layer_names[i], i
		);
	}

	result->nb_channels = MLV_get_number_of_objects_from_xml(
		xml, "/animation_book/channels/channel"
	);
	result->channel_names = MLV_MALLOC(
		result->nb_channels, char*
	);
	g_datalist_init( &(result->channel_name_to_id) );
	for( i=0; i<result->nb_channels; i++ ){
		result->channel_names[i] = MLV_get_string_value_from_xml(
			xml, 0, "/animation_book/channels/channel[%d]", i+1
		);
		insret_data_in_map(
			&(result->channel_name_to_id), result->channel_names[i], i
		);
	}


	result->nb_pages = MLV_get_number_of_objects_from_xml(
		xml, "/animation_book/page"
	);
	result->page_names = MLV_MALLOC(
		result->nb_pages, char*
	);
	g_datalist_init( &(result->page_name_to_id) );
	for( i=0; i<result->nb_pages; i++ ){
		result->page_names[i] = MLV_get_string_value_from_xml(
			xml, 0, "/animation_book/page[%d]/name", i+1
		);
		insret_data_in_map(
			&(result->page_name_to_id), result->page_names[i], i
		);
	}
	result->pages = MLV_MALLOC(
		result->nb_pages, Animation_book_page
	);

	result->nb_sounds = MLV_get_number_of_objects_from_xml(
		xml, "/animation_book/sound"
	);
	result->sound_names = MLV_MALLOC(
		result->nb_sounds, char*
	);
	g_datalist_init( &(result->sound_name_to_id) );
	for( i=0; i<result->nb_sounds; i++ ){
		result->sound_names[i] = MLV_get_string_value_from_xml(
			xml, 0, "/animation_book/sound[%d]/name", i+1
		);
		insret_data_in_map(
			&(result->sound_name_to_id), result->sound_names[i], i
		);
	}
	result->sounds = MLV_MALLOC(
		result->nb_sounds, Animation_book_sound
	);
	
	int nb_layers = result->nb_layers;
	int nb_channels = result->nb_channels;
	int nb_pages = result->nb_pages;
	int nb_sounds = result->nb_sounds;
	int nb_animation_sequences = result->nb_animation_sequences;

	int id_page;
	for( id_page=0; id_page<nb_pages; id_page++ ){
		result->pages[id_page].width =  MLV_get_integer_value_from_xml(
			xml, 0, "/animation_book/page[%d]/width", id_page+1
		);
		result->pages[id_page].height =  MLV_get_integer_value_from_xml(
			xml, 0, "/animation_book/page[%d]/height", id_page+1
		);
		result->pages[id_page].columns =  MLV_get_integer_value_from_xml(
			xml, 0, "/animation_book/page[%d]/columns", id_page+1
		);
		result->pages[id_page].layers = MLV_MALLOC( nb_layers, MLV_Image* );
		for( i=0; i < nb_layers; i++ ){
			result->pages[id_page].layers[i] = NULL;
		}

		int nb_images = MLV_get_number_of_objects_from_xml(
			xml, "/animation_book/page[%d]/image", id_page+1
		);
		int image;
		for( image=0; image < nb_images; image++ ){
			char* layer = MLV_get_string_value_from_xml(
				xml, 0, "/animation_book/page[%d]/image[%d]/layer", id_page+1, 
				image+1
			);
			char* file = MLV_get_string_value_from_xml(
				xml, 0, "/animation_book/page[%d]/image[%d]/file", id_page+1,
				image+1
			);
			int id_layer = *(
				(int*) g_datalist_get_data(
					&(result->layer_name_to_id), layer
				)
			);

			if( MLV_path_is_absolute( file ) ){
				result->pages[id_page].layers[ id_layer ] = MLV_load_image(
					file
				);
			}else{
				char* full_path;
				if( image_directory ){
					full_path = MLV_build_path(
						image_directory, file, NULL
					);
				}else{
					full_path = MLV_build_path( dirname, file, NULL );
				}
				result->pages[id_page].layers[ id_layer ] = MLV_load_image(
					full_path
				);
				MLV_FREE( full_path, char );
			}

			MLV_FREE( layer, char );
			MLV_FREE( file, char );
		}
		
	}


	int id_sound;
	for( id_sound=0; id_sound<nb_sounds; id_sound++ ){
		result->sounds[id_sound].channels = MLV_MALLOC( nb_channels, MLV_Sound* );
		for( i=0; i < nb_channels; i++ ){
			result->sounds[id_sound].channels[i] = NULL;
		}

		int nb_samples = MLV_get_number_of_objects_from_xml(
			xml, "/animation_book/sound[%d]/sample", id_sound+1
		);
		int sample;
		for( sample=0; sample < nb_samples; sample++ ){
			char* channel = MLV_get_string_value_from_xml(
				xml, 0, "/animation_book/sound[%d]/sample[%d]/channel", id_sound+1, 
				sample+1
			);
			char* file = MLV_get_string_value_from_xml(
				xml, 0, "/animation_book/sound[%d]/sample[%d]/file", id_sound+1,
				sample+1
			);
			int id_channel = *(
				(int*) g_datalist_get_data(
					&(result->channel_name_to_id), channel
				)
			);

			if( MLV_path_is_absolute( file ) ){
				result->sounds[id_sound].channels[ id_channel ] = MLV_load_sound(
					file
				);
			}else{
				char* full_path;
				if( sound_directory ){
					full_path = MLV_build_path(
						sound_directory, file, NULL
					);
				}else{
					full_path = MLV_build_path( dirname, file, NULL );
				}
				result->sounds[id_sound].channels[ id_channel ] = MLV_load_sound(
					full_path
				);
				MLV_FREE( full_path, char );
			}

			MLV_FREE( channel, char );
			MLV_FREE( file, char );
		}
	}


	int id_animation;
	for( id_animation=0; id_animation<nb_animation_sequences; id_animation++ ){
		char* page_name = MLV_get_string_value_from_xml(
			xml, 0, "/animation_book/animation[%d]/page", id_animation+1
		);
		int id_page = *(
			(int*) g_datalist_get_data(
				&(result->page_name_to_id), page_name
			)
		);
		int width = result->pages[id_page].width;
		int height = result->pages[id_page].height;
		int columns = result->pages[id_page].columns;
		int nb_frames = MLV_get_number_of_objects_from_xml(
			xml, "/animation_book/animation[%d]/frame", id_animation+1
		);
		result->animation_sequences[
			id_animation
		] = MLV_create_animation_sequence( nb_frames, nb_layers, nb_channels );
		int id_frame;
		for( id_frame=0; id_frame < nb_frames; id_frame++ ){
			MLV_Sound** sounds = NULL;
			MLV_Image** images = NULL;
			char* sound = MLV_get_string_value_from_xml(
				xml, 0, "/animation_book/animation[%d]/frame[%d]/sound",
				id_animation+1,	id_frame+1
			);
			if( sound ){
				int id_sound = *(
					(int*) g_datalist_get_data(
						&(result->sound_name_to_id), sound
					)
				);
				sounds = result->sounds[id_sound].channels;
			}
			int panel = MLV_get_integer_value_from_xml(
				xml, 0, "/animation_book/animation[%d]/frame[%d]/panel", 
				id_animation+1, id_frame+1 
			);
			images = MLV_MALLOC( nb_layers ,MLV_Image* );
			int id_layer;
			for( id_layer=0; id_layer<nb_layers; id_layer++ ){
				int x = (panel%columns)*(width+1);
				int y = (panel/columns)*(height+1);
				if(result->pages[id_page].layers[id_layer]){
					images[id_layer] = MLV_copy_partial_image(
						result->pages[id_page].layers[id_layer],
						x, y, width, height
					);
				}else{
					images[id_layer] = NULL;
				}
			}
			int time = MLV_get_integer_value_from_xml(
				xml, 0, "/animation_book/animation[%d]/frame[%d]/time", 
				id_animation+1, id_frame+1 
			);
			MLV_add_frame_in_animation_sequence(
				images, sounds,  time, result->animation_sequences[id_animation]
			);
			MLV_FREE( images, MLV_Image* );
			MLV_FREE( sound, char );
		}
	}

	MLV_FREE( dirname, char );
	MLV_free_xml( xml );

	return result;
}

void MLV_free_animation_book(
	MLV_Animation_book* animation_book
){
	if( !animation_book ) return;

	int i;

	int id_animation;
	for( id_animation=0; id_animation < animation_book->nb_animation_sequences;
		id_animation++
	){
		MLV_Animation_sequence* sequence;
		sequence = animation_book->animation_sequences[id_animation];
		int id_frame;
		for( id_frame=0; id_frame < sequence->nb_frames; id_frame++ ){
			int id_layer;
			MLV_Image** images = sequence->frames[id_frame].images; 
			for( id_layer=0; id_layer<animation_book->nb_layers; id_layer++ ){
				if( images[id_layer] ){
					MLV_free_image( images[id_layer] );
				}
			}
		}
		MLV_free_animation_sequence( sequence );
	}


	int id_sound;
	for( id_sound=0; id_sound< animation_book->nb_sounds; id_sound++ ){
		int id_channel;
		for(
			id_channel=0; id_channel < animation_book->nb_channels; 
			id_channel++
		){
			if( animation_book->sounds[id_sound].channels[ id_channel ] ){
				MLV_free_sound(
					animation_book->sounds[id_sound].channels[id_channel]
				);
			}
		}
		MLV_FREE( animation_book->sounds[id_sound].channels, MLV_Image* );
	}
	g_datalist_clear( &animation_book->sound_name_to_id );
	for( i=0; i<animation_book->nb_sounds; i++ ){
		MLV_FREE( animation_book->sound_names[i], char );
	}
	MLV_FREE( animation_book->sound_names, char* );
	MLV_FREE( animation_book->sounds, Animation_book_sound );

	int id_page;
	for( id_page=0; id_page< animation_book->nb_pages; id_page++ ){
		int id_layer;
		for( id_layer=0; id_layer < animation_book->nb_layers; id_layer++ ){
			if( animation_book->pages[id_page].layers[ id_layer ] ){
				MLV_free_image(
					animation_book->pages[id_page].layers[id_layer]
				);
			}
		}
		MLV_FREE( animation_book->pages[id_page].layers, MLV_Image* );
	}
	g_datalist_clear( &animation_book->page_name_to_id );
	for( i=0; i<animation_book->nb_pages; i++ ){
		MLV_FREE( animation_book->page_names[i], char );
	}
	MLV_FREE( animation_book->page_names, char* );
	MLV_FREE( animation_book->pages, Animation_book_page );

	g_datalist_clear( &animation_book->channel_name_to_id );
	for( i=0; i<animation_book->nb_channels; i++ ){
		MLV_FREE( animation_book->channel_names[i], char );
	}
	MLV_FREE( animation_book->channel_names, char* );

	g_datalist_clear( &animation_book->layer_name_to_id );
	for( i=0; i<animation_book->nb_layers; i++ ){
		MLV_FREE( animation_book->layer_names[i], char );
	}
	MLV_FREE( animation_book->layer_names, char* );

	g_datalist_clear( &animation_book->animation_name_to_id );
	for( i=0; i<animation_book->nb_animation_sequences; i++ ){
		MLV_FREE( animation_book->animation_names[i], char );
	}
	MLV_FREE( animation_book->animation_names, char* );
	MLV_FREE( animation_book->animation_sequences, MLV_Animation_sequence* );

	MLV_FREE( animation_book, MLV_Animation_book );
}

MLV_Animation_sequence* MLV_get_animation_from_id(
	MLV_Animation_book* animation_book,
	int id
){
	return animation_book->animation_sequences[id];
}

MLV_Animation_sequence* MLV_get_animation_from_name(
	MLV_Animation_book* animation_book,
	const char* name
){
	int* id_ptr =(int*) g_datalist_get_data(
		&(animation_book->animation_name_to_id), name
	);
	if( !id_ptr ) return NULL;
	return MLV_get_animation_from_id( animation_book, *id_ptr );
}

const char* MLV_get_name_from_id_animation(
	MLV_Animation_book* animation_book, int id_animation
){
	return animation_book->animation_names[ id_animation ];
}

